==> openshift-model-hive-5.12.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DNSZoneSpecBuilder extends io.fabric8.openshift.api.model.hive.v1.DNSZoneSpecFluentImpl<io.fabric8.openshift.api.model.hive.v1.DNSZoneSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.DNSZoneSpec,io.fabric8.openshift.api.model.hive.v1.DNSZoneSpecBuilder>{
  public DNSZoneSpecBuilder() {
    this(false);
  }
  public DNSZoneSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new DNSZoneSpec(), validationEnabled);
  }
  public DNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DNSZoneSpec(), validationEnabled);
  }
  public DNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZoneSpec instance) {
    this(fluent, instance, false);
  }
  public DNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.DNSZoneSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAws(instance.getAws()); 
    fluent.withAzure(instance.getAzure()); 
    fluent.withGcp(instance.getGcp()); 
    fluent.withLinkToParentDomain(instance.getLinkToParentDomain()); 
    fluent.withPreserveOnDelete(instance.getPreserveOnDelete()); 
    fluent.withZone(instance.getZone()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneSpec instance) {
    this(instance,false);
  }
  public DNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.DNSZoneSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAws(instance.getAws()); 
    this.withAzure(instance.getAzure()); 
    this.withGcp(instance.getGcp()); 
    this.withLinkToParentDomain(instance.getLinkToParentDomain()); 
    this.withPreserveOnDelete(instance.getPreserveOnDelete()); 
    this.withZone(instance.getZone()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.DNSZoneSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.DNSZoneSpec build() {
    DNSZoneSpec buildable = new DNSZoneSpec(fluent.getAws(),fluent.getAzure(),fluent.getGcp(),fluent.getLinkToParentDomain(),fluent.getPreserveOnDelete(),fluent.getZone());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSZoneSpecBuilder that = (DNSZoneSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.3.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/DNSZoneSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DNSZoneSpecBuilder extends DNSZoneSpecFluentImpl<DNSZoneSpecBuilder> implements VisitableBuilder<DNSZoneSpec,DNSZoneSpecBuilder>{
  public DNSZoneSpecBuilder() {
    this(false);
  }
  public DNSZoneSpecBuilder(Boolean validationEnabled) {
    this(new DNSZoneSpec(), validationEnabled);
  }
  public DNSZoneSpecBuilder(DNSZoneSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public DNSZoneSpecBuilder(DNSZoneSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DNSZoneSpec(), validationEnabled);
  }
  public DNSZoneSpecBuilder(DNSZoneSpecFluent<?> fluent,DNSZoneSpec instance) {
    this(fluent, instance, false);
  }
  public DNSZoneSpecBuilder(DNSZoneSpecFluent<?> fluent,DNSZoneSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAws(instance.getAws()); 
    fluent.withAzure(instance.getAzure()); 
    fluent.withGcp(instance.getGcp()); 
    fluent.withLinkToParentDomain(instance.getLinkToParentDomain()); 
    fluent.withPreserveOnDelete(instance.getPreserveOnDelete()); 
    fluent.withZone(instance.getZone()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DNSZoneSpecBuilder(DNSZoneSpec instance) {
    this(instance,false);
  }
  public DNSZoneSpecBuilder(DNSZoneSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAws(instance.getAws()); 
    this.withAzure(instance.getAzure()); 
    this.withGcp(instance.getGcp()); 
    this.withLinkToParentDomain(instance.getLinkToParentDomain()); 
    this.withPreserveOnDelete(instance.getPreserveOnDelete()); 
    this.withZone(instance.getZone()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DNSZoneSpecFluent<?> fluent;
  Boolean validationEnabled;
  public DNSZoneSpec build() {
    DNSZoneSpec buildable = new DNSZoneSpec(fluent.getAws(),fluent.getAzure(),fluent.getGcp(),fluent.getLinkToParentDomain(),fluent.getPreserveOnDelete(),fluent.getZone());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
